types_equal

Function types_equal 

pub fn types_equal(a: &Type, b: &Type, subst: &Substitution) -> bool
Check structural equivalence of two types under a substitution.

Two types are equivalent if unify succeeds on a fresh scratch substitution that extends the given one (non-destructively).