pub struct ResolvedMethod {
pub impl_id: ImplId,
pub trait_ref: Option<TraitRef>,
pub method: String,
}Expand description
The result of a successful method dispatch via resolve_method.
Fields
impl_id: ImplIdThe impl block that provides this method.
trait_ref: Option<TraitRef>The trait this method comes from, or None for inherent impls.
method: StringThe resolved method name.