pub fn types_equal(a: &Type, b: &Type, subst: &Substitution) -> boolExpand description
Check structural equivalence of two types under a substitution.
Two types are equivalent if unify succeeds on a fresh scratch
substitution that extends the given one (non-destructively).